english_word_dict = {
    "main_window_current_filename_format": "Current Filename: {name}",
    # File menu
    "main_window_open_image": "Open File",
    "main_window_current_filename": "Current Filename:",
    "main_window_current_file": "File",
    "main_window_open_folder": "Open Folder",
    "main_window_exit": "Exit",
    "main_window_tile_size": "Thumbnail Size",
    "main_window_select_folder": "Select Folder",
    "main_window_select_image": "Select Image",
    "main_window_current_folder_format": "Current Folder: {path}",
    "main_window_remove_undo_stack": "Remove temp undo files",
    # Language Menubar
    "menu_bar_language": "Language",
    "language_menu_bar_please_restart_messagebox": "Please restart",
    "language_menu_bar_english": "English",
    "language_menu_bar_traditional_chinese": "Traditional Chinese",
    "language_menu_bar_chinese": "Chinese",
    "language_menu_bar_koren": "Korean",
    "language_menu_bar_japanese": "Japanese",
    # Tip menu
    "main_window_tip_menu": "Instructions",
    "main_window_mouse_tip_menu": "Mouse Control",
    "main_window_keyboard_tip_menu": "Keyboard Control",
    "mouse_control_middle_tip": "You can move using the mouse middle button",
    "mouse_control_left_tip": "Clicking an image with the left mouse button enters Deep zoom mode",
    "mouse_control_multi_select_tip": "Hold down the left mouse button to multi-select images in thumbnail mode",
    "keyboard_control_esc_tip": "Press ESC to exit Deep zoom mode",
    "keyboard_control_tile_arrow_up_tip": "In thumbnail mode, use the Up arrow key to move upward",
    "keyboard_control_tile_arrow_down_tip": "In thumbnail mode, use the Down arrow key to move downward",
    "keyboard_control_tile_arrow_left_tip": "In thumbnail mode, use the Left arrow key to move left",
    "keyboard_control_tile_arrow_right_tip": "In thumbnail mode, use the Right arrow key to move right",
    "keyboard_control_delete_tip": "Press Delete to move images to the Recycle Bin (thumbnail and Deep zoom modes)",
    "keyboard_r_tip": "In Deep zoom mode, press R / Shift+R to rotate clockwise / counter-clockwise",
    "keyboard_home_tip": "Press Home to reset zoom and position to default",
    "keyboard_e_tip": "Press E to open the image editor",
    "keyboard_undo_tip": "Undo the last action",
    "keyboard_redo_tip": "Redo the last undone action",
    "keyboard_arrow_lr_tip": "In Deep zoom mode, press Left / Right to switch images",
    "keyboard_arrow_tile_tip": "In thumbnail mode, use arrow keys to navigate",
    "tip_mouse_middle": "Middle Button",
    "tip_mouse_left_click": "Left Click",
    "tip_mouse_left_drag": "Left Drag",
    "tip_mouse_right_desc": "Open the context menu with various actions",
    "tip_mouse_scroll_desc": "Scroll to zoom in/out or scroll through thumbnails",
    "tip_close": "Close",
    "tip_show_shortcuts": "Keyboard & Mouse Shortcuts",
    "keyboard_f_tip": "Press F to toggle fullscreen, Esc to exit",
    "keyboard_ctrl_c_tip": "Press Ctrl+C to copy the current image to the clipboard",
    "keyboard_rating_tip": "Press 1~5 to rate the current image; press again to clear",
    "keyboard_search_tip": "Press / or Ctrl+F to search images by name",
    "keyboard_favorite_tip": "Press 0 to toggle favorite on the current image",
    "keyboard_slideshow_tip": "Press S to start/stop slideshow",
    # Rating status
    "rating_set": "Rating: {star}",
    "rating_cleared": "Rating cleared",
    # Search dialog
    "search_dialog_title": "Search Images",
    "search_dialog_placeholder": "Type to search...",
    "search_open": "Open",
    # Right click menu
    "right_click_menu_go_to_parent_folder": "Go to Parent Folder",
    "right_click_menu_next_image": "Next Image",
    "right_click_menu_previous_image": "Previous Image",
    "right_click_menu_delete_current": "Delete Current Image",
    "right_click_menu_delete_selected": "Delete Selected Images",
    "right_click_menu_image_info": "Image Info",
    # Image info
    "image_info_filename": "Filename: {info}\n",
    "image_info_fullpath": "Full Path: {full_path}\n",
    "image_info_image_size": "Size: {width} x {height}\n",
    "image_info_file_size": "File Size: {file_size_mb} MB\n",
    "image_info_file_created_time": "Created Time: {created_time}\n",
    "image_info_file_modified_time": "Modified Time: {modified_time}\n",
    "image_info_messagebox_title": "Image Info",
    # Image info exif
    "image_info_exif_datatime_original": "Taken Time: {DateTimeOriginal}\n",
    "image_info_exif_camera_model": "Camera: {Make} {Model}\n",
    "image_info_exif_camera_lens_model": "Lens: {LensModel}\n",
    "image_info_exif_camera_focal_length": "Focal Length: {FocalLength}\n",
    "image_info_exif_camera_fnumber": "Aperture: {FNumber}\n",
    "image_info_exif_exposure_time": "Shutter: {ExposureTime}\n",
    "image_info_exif_iso": "ISO: {ISOSpeedRatings}",
    # Recent menu
    "recent_menu_title": "Recently Opened Menu",
    # Plugin
    "plugin_menu_title": "Plugins",
    "plugin_menu_loaded": "Loaded Plugins",
    "plugin_menu_no_plugins": "No plugins loaded",
    "plugin_menu_reload": "Reload Plugins",
    "plugin_menu_open_folder": "Open Plugin Folder",
    "plugin_info_name": "Name: {name}",
    "plugin_info_version": "Version: {version}",
    "plugin_info_author": "Author: {author}",
    "plugin_info_description": "Description: {description}",
    "plugin_info_languages": "Languages: {languages}",
    "plugin_menu_manage": "Manage Plugins",
    "plugin_manage_count": "{count} plugin(s) loaded",
    "plugin_manage_select_hint": "Select a plugin to view details",
    "plugin_reload_confirm": "Reload all plugins? This will unload current plugins and re-discover them.",
    "plugin_reload_done": "Reloaded {count} plugin(s)",
    "plugin_menu_download": "Download Plugins",
    # Plugin Downloader
    "plugin_dl_title": "Download Plugins",
    "plugin_dl_refresh": "Refresh",
    "plugin_dl_col_name": "Plugin",
    "plugin_dl_col_status": "Status",
    "plugin_dl_download": "Download",
    "plugin_dl_reinstall": "Reinstall",
    "plugin_dl_delete": "Delete",
    "plugin_dl_close": "Close",
    "plugin_dl_installed": "Installed",
    "plugin_dl_not_installed": "Not Installed",
    "plugin_dl_status_ready": "Ready",
    "plugin_dl_status_fetching": "Fetching plugin list...",
    "plugin_dl_status_found": "Found {count} plugin(s)",
    "plugin_dl_status_error": "Error: {error}",
    "plugin_dl_status_downloading": "Downloading {name}...",
    "plugin_dl_status_done": "Downloaded {name} successfully!",
    "plugin_dl_status_deleted": "Deleted {name}.",
    "plugin_dl_restart_hint": "Plugin '{name}' downloaded. Restart Imervue to activate it.",
    "plugin_dl_delete_confirm_title": "Delete Plugin",
    "plugin_dl_delete_confirm": "Delete plugin '{name}'?",
    # Right-click menu
    "right_click_show_in_explorer": "Show in Explorer",
    "right_click_copy_path": "Copy Path",
    "right_click_copy_image": "Copy Image",
    "right_click_rotate_cw": "Rotate Clockwise",
    "right_click_rotate_ccw": "Rotate Counter-clockwise",
    "right_click_set_wallpaper": "Set as Wallpaper",
    "right_click_compare": "Compare Images",
    "right_click_slideshow": "Slideshow",
    "right_click_slideshow_stop": "Stop Slideshow",
    # Sort menu
    "sort_menu_title": "Sort",
    "sort_by_name": "By Name",
    "sort_by_modified": "By Modified Date",
    "sort_by_created": "By Created Date",
    "sort_by_size": "By File Size",
    "sort_by_resolution": "By Resolution",
    "sort_ascending": "Ascending",
    "sort_descending": "Descending",
    # Filter menu
    "filter_menu_title": "Filter",
    "filter_by_extension": "By Extension",
    "filter_by_rating": "By Rating",
    "filter_ext_all": "All",
    "filter_ext_jpg": "JPEG",
    "filter_ext_png": "PNG",
    "filter_ext_bmp": "BMP",
    "filter_ext_tiff": "TIFF",
    "filter_ext_raw": "RAW",
    "filter_rating_all": "All",
    "filter_rating_favorited": "Favorited",
    "filter_clear": "Clear Filter",
    # Favorite
    "favorite_added": "\u2764 Favorited",
    "favorite_removed": "Favorite removed",
    # Compare
    "compare_title": "Compare Images",
    "compare_2": "Compare 2",
    "compare_4": "Compare 4",
    # EXIF sidebar
    "exif_filename": "File",
    "exif_filesize": "Size",
    "exif_created": "Created",
    "exif_modified": "Modified",
    "exif_taken": "Taken",
    "exif_make": "Make",
    "exif_model": "Model",
    "exif_lens": "Lens",
    "exif_focal": "Focal Length",
    "exif_aperture": "Aperture",
    "exif_shutter": "Shutter",
    "exif_iso": "ISO",
    "exif_ev": "EV",
    "exif_wb": "White Balance",
    "exif_flash": "Flash",
    "exif_resolution": "Resolution",
    "exif_no_data": "No EXIF data",
    # Slideshow
    "slideshow_title": "Slideshow",
    "slideshow_interval": "Interval (sec):",
    "slideshow_fade": "Fade transition",
    "slideshow_start": "Start",
    "slideshow_cancel": "Cancel",
    # Status bar
    "status_loading_progress": "Loading {current}/{total}...",
    "status_loading_image": "Loading image...",
    "status_ready": "Ready",
    # Toast
    "toast_path_copied": "Path copied",
    # Right-click extras
    "right_click_edit_image": "Edit Image",
    "right_click_batch": "Batch Operations",
    "batch_rename_title": "Batch Rename",
    "batch_rename_hint": "Template: {name} = original, {n} = sequence, {ext} = extension",
    "batch_rename_start": "Start number:",
    "batch_rename_apply": "Rename",
    "batch_rename_cancel": "Cancel",
    "batch_move_title": "Move / Copy",
    "batch_move_mode": "Mode",
    "batch_move_move": "Move",
    "batch_move_copy": "Copy",
    "batch_move_apply": "Apply",
    "batch_move_cancel": "Cancel",
    "batch_rotate_cw": "Rotate All CW",
    "batch_rotate_ccw": "Rotate All CCW",
    # Image editor
    "editor_title": "Image Editor",
    "editor_brightness": "Brightness",
    "editor_contrast": "Contrast",
    "editor_saturation": "Saturation",
    "editor_apply_crop": "Apply Crop",
    "editor_rotate_cw": "Rotate CW",
    "editor_rotate_ccw": "Rotate CCW",
    "editor_reset": "Reset",
    "editor_save_as": "Save As...",
    "editor_save": "Save",
    "editor_saved": "Saved!",
    # EXIF editor
    "exif_edit_button": "Edit EXIF",
    "exif_editor_title": "Edit EXIF Metadata",
    "exif_editor_no_piexif": "piexif package required.\nInstall: pip install piexif",
    "exif_editor_fields": "Metadata Fields",
    "exif_editor_save": "Save",
    "exif_editor_cancel": "Cancel",
    "exif_editor_close": "Close",
    "exif_editor_saved": "EXIF saved!",
    "exif_edit_description": "Description",
    "exif_edit_artist": "Artist",
    "exif_edit_copyright": "Copyright",
    "exif_edit_make": "Make",
    "exif_edit_model": "Model",
    "exif_edit_user_comment": "User Comment",
    # Export dialog
    "export_title": "Export Image",
    "export_format": "Format:",
    "export_quality": "Quality:",
    "export_browse": "Browse...",
    "export_save": "Save",
    "export_cancel": "Cancel",
    "export_saved": "Exported successfully!",
    # Histogram
    "histogram_toggle": "Press H to toggle RGB histogram",
    # Lossless rotation
    "lossless_rotate_cw": "Lossless Rotate CW",
    "lossless_rotate_ccw": "Lossless Rotate CCW",
    "lossless_rotate_done": "Lossless rotation saved!",
    "lossless_rotate_fail": "Lossless rotation failed",
    # Right-click additions
    "right_click_export": "Export / Save As...",
    "right_click_lossless_rotate": "Lossless Rotate",
    # Animation playback
    "anim_play": "Play",
    "anim_pause": "Pause",
    "anim_frame_prev": "Previous Frame",
    "anim_frame_next": "Next Frame",
    "anim_frame_indicator": "Frame {current}/{total}",
    "anim_speed": "Speed: {speed}x",
    # File association
    "file_assoc_menu": "File Association",
    "file_assoc_register": "Register 'Open with Imervue'",
    "file_assoc_unregister": "Remove file association",
    "file_assoc_done": "File association registered!",
    "file_assoc_removed": "File association removed!",
    "file_assoc_need_admin": "Administrator privileges required",
    # Multi-window
    "menu_new_window": "New Window",
    # Fit modes
    "fit_width": "Fit Width",
    "fit_height": "Fit Height",
    "keyboard_w_tip": "Press W to fit width, Shift+W to fit height",
    # Additional keyboard tips
    "keyboard_h_tip": "Press H to toggle RGB histogram in Deep zoom mode",
    "keyboard_ctrl_v_tip": "Press Ctrl+V to paste image from clipboard",
    "keyboard_anim_play_tip": "Press Space to play/pause animated images (GIF/APNG/WebP)",
    "keyboard_anim_frame_tip": "Press < / > to step through animation frames",
    "keyboard_anim_speed_tip": "Press [ / ] to decrease/increase animation speed",
    # Bookmarks
    "bookmark_title": "Bookmarks",
    "bookmark_open": "Open",
    "bookmark_remove": "Remove",
    "bookmark_clear": "Clear All",
    "bookmark_close": "Close",
    "bookmark_count": "{count} bookmarked image(s)",
    "bookmark_added": "\u2605 Bookmarked",
    "bookmark_removed": "Bookmark removed",
    "bookmark_add_current": "Add Bookmark",
    "bookmark_remove_current": "Remove Bookmark",
    "bookmark_clear_confirm_title": "Clear Bookmarks",
    "bookmark_clear_confirm": "Remove all bookmarks?",
    "keyboard_b_tip": "Press B to toggle bookmark on current image",
    # SVG
    "filter_ext_svg": "SVG",
    # Tags & Albums
    "tag_album_title": "Tags & Albums",
    "tag_tab_tags": "Tags",
    "tag_tab_albums": "Albums",
    "tag_close": "Close",
    "tag_count": "{count} tag(s)",
    "tag_create": "New Tag",
    "tag_rename": "Rename",
    "tag_delete": "Delete",
    "tag_images": "Images in tag:",
    "tag_remove_image": "Remove from Tag",
    "tag_filter": "Show in Viewer",
    "tag_create_prompt": "Tag name:",
    "tag_rename_prompt": "New name:",
    "tag_delete_confirm_title": "Delete Tag",
    "tag_delete_confirm": "Delete tag '{name}'?",
    "tag_menu_title": "Tags",
    "tag_create_and_add": "+ New Tag...",
    "album_count": "{count} album(s)",
    "album_create": "New Album",
    "album_rename": "Rename",
    "album_delete": "Delete",
    "album_images": "Images in album:",
    "album_remove_image": "Remove from Album",
    "album_view": "View Album",
    "album_create_prompt": "Album name:",
    "album_rename_prompt": "New name:",
    "album_delete_confirm_title": "Delete Album",
    "album_delete_confirm": "Delete album '{name}'?",
    "album_menu_title": "Albums",
    "album_create_and_add": "+ New Album...",
    "batch_tag_title": "Add to Tag",
    "batch_album_title": "Add to Album",
    "filter_by_tag": "By Tag",
    "filter_by_album": "By Album",
    "filter_no_tags": "(No tags)",
    "filter_no_albums": "(No albums)",
    "keyboard_t_tip": "Press T to open Tags & Albums manager",
    # Batch Export
    "batch_export_title": "Batch Export",
    "batch_export_count": "{count} image(s) selected",
    "batch_export_resize": "Resize",
    "batch_export_max_width": "Max Width:",
    "batch_export_max_height": "Max Height:",
    "batch_export_start": "Export",
    "batch_export_done": "Exported {success}/{total} image(s)",
    # GIF / Video
    "gif_video_title": "Create GIF / Video",
    "gif_video_order": "Drag to reorder (top = first frame):",
    "gif_video_move_up": "Move Up",
    "gif_video_move_down": "Move Down",
    "gif_video_settings": "Settings",
    "gif_video_fps": "FPS:",
    "gif_video_width": "Width:",
    "gif_video_height": "Height:",
    "gif_video_auto": "Auto",
    "gif_video_loop": "Loop forever",
    "gif_video_create": "Create",
    "gif_video_save": "Save As",
    "gif_video_done": "Created: {path}",
}