japanese_word_dict = {
    "main_window_current_filename_format": "現在のファイル名: {name}",
    # File menu
    "main_window_open_image": "ファイルを開く",
    "main_window_current_filename": "現在のファイル名:",
    "main_window_current_file": "ファイル",
    "main_window_open_folder": "フォルダーを開く",
    "main_window_exit": "終了",
    "main_window_tile_size": "サムネイルサイズ",
    "main_window_select_folder": "フォルダーを選択",
    "main_window_select_image": "画像を選択",
    "main_window_current_folder_format": "現在のフォルダー: {path}",
    "main_window_remove_undo_stack": "一時的な取り消しファイルを削除",
    # Language Menubar
    "menu_bar_language": "言語",
    "language_menu_bar_please_restart_messagebox": "再起動してください",
    "language_menu_bar_english": "英語",
    "language_menu_bar_traditional_chinese": "繁体字中国語",
    "language_menu_bar_chinese": "簡体字中国語",
    "language_menu_bar_koren": "韓国語",
    "language_menu_bar_japanese": "日本語",
    # Tip menu
    "main_window_tip_menu": "使用説明",
    "mouse_control_middle_tip": "マウスの中ボタンで移動できます",
    "main_window_mouse_tip_menu": "マウス操作",
    "main_window_keyboard_tip_menu": "キーボード操作",
    "mouse_control_left_tip": "マウス左ボタンで画像をクリックすると Deep zoom モードに入ります",
    "mouse_control_multi_select_tip": "マウスの左ボタンを押したままにすると、サムネイルモードで複数の画像を選択できます",
    "keyboard_control_esc_tip": "Deep zoom モードでは ESC キーで終了できます",
    "keyboard_control_tile_arrow_up_tip": "サムネイルモードでは矢印キーの上で上に移動できます",
    "keyboard_control_tile_arrow_down_tip": "サムネイルモードでは矢印キーの下で下に移動できます",
    "keyboard_control_tile_arrow_left_tip": "サムネイルモードでは矢印キーの左で左に移動できます",
    "keyboard_control_tile_arrow_right_tip": "サムネイルモードでは矢印キーの右で右に移動できます",
    "keyboard_control_delete_tip": "Delete キーで画像をごみ箱に移動できます（サムネイル・Deep zoom 両モード対応）",
    "keyboard_r_tip": "Deep zoom モードでは R / Shift+R で時計回り/反時計回りに回転",
    "keyboard_home_tip": "Home キーでズームと位置をデフォルトにリセット",
    "keyboard_e_tip": "E キーで画像エディターを開く",
    "keyboard_undo_tip": "直前の操作を元に戻す",
    "keyboard_redo_tip": "元に戻した操作をやり直す",
    "keyboard_arrow_lr_tip": "Deep zoom モードで左/右キーで画像を切り替え",
    "keyboard_arrow_tile_tip": "サムネイルモードで矢印キーで移動",
    "tip_mouse_middle": "中ボタン",
    "tip_mouse_left_click": "左クリック",
    "tip_mouse_left_drag": "左ドラッグ",
    "tip_mouse_right_desc": "コンテキストメニューを開き、各種操作を実行",
    "tip_mouse_scroll_desc": "スクロールでズームイン/アウトまたはサムネイルをスクロール",
    "tip_close": "閉じる",
    "tip_show_shortcuts": "キーボード・マウスのショートカット",
    "keyboard_f_tip": "F キーでフルスクリーン切替、Esc で終了",
    "keyboard_ctrl_c_tip": "Ctrl+C で現在の画像をクリップボードにコピー",
    "keyboard_rating_tip": "1~5 キーで現在の画像を評価；もう一度押すと解除",
    "keyboard_search_tip": "/ または Ctrl+F で画像名を検索",
    "keyboard_favorite_tip": "0 キーで現在の画像をお気に入りに追加/解除",
    "keyboard_slideshow_tip": "S キーでスライドショーの開始/停止",
    # 評価ステータス
    "rating_set": "評価：{star}",
    "rating_cleared": "評価をクリアしました",
    # 検索ダイアログ
    "search_dialog_title": "画像を検索",
    "search_dialog_placeholder": "検索キーワードを入力...",
    "search_open": "開く",
    # Right click menu
    "right_click_menu_go_to_parent_folder": "親フォルダへ移動",
    "right_click_menu_next_image": "次の画像",
    "right_click_menu_previous_image": "前の画像",
    "right_click_menu_delete_current": "現在の画像を削除",
    "right_click_menu_delete_selected": "選択した画像を削除",
    "right_click_menu_image_info": "画像情報",
    # Image info
    "image_info_filename": "ファイル名: {info}\n",
    "image_info_fullpath": "フルパス: {full_path}\n",
    "image_info_image_size": "サイズ: {width} x {height}\n",
    "image_info_file_size": "ファイルサイズ: {file_size_mb} MB\n",
    "image_info_file_created_time": "作成日時: {created_time}\n",
    "image_info_file_modified_time": "更新日時: {modified_time}\n",
    "image_info_messagebox_title": "画像情報",
    # Image info exif
    "image_info_exif_datatime_original": "撮影日時: {DateTimeOriginal}\n",
    "image_info_exif_camera_model": "カメラ: {Make} {Model}\n",
    "image_info_exif_camera_lens_model": "レンズ: {LensModel}\n",
    "image_info_exif_camera_focal_length": "焦点距離: {FocalLength}\n",
    "image_info_exif_camera_fnumber": "絞り値: {FNumber}\n",
    "image_info_exif_exposure_time": "シャッター速度: {ExposureTime}\n",
    "image_info_exif_iso": "ISO: {ISOSpeedRatings}",
    # Recent menu
    "recent_menu_title": "最近開いたメニュー",
    # Plugin
    "plugin_menu_title": "プラグイン",
    "plugin_menu_loaded": "読み込み済みプラグイン",
    "plugin_menu_no_plugins": "プラグインが読み込まれていません",
    "plugin_menu_reload": "プラグインを再読み込み",
    "plugin_menu_open_folder": "プラグインフォルダーを開く",
    "plugin_info_name": "名前：{name}",
    "plugin_info_version": "バージョン：{version}",
    "plugin_info_author": "作者：{author}",
    "plugin_info_description": "説明：{description}",
    "plugin_info_languages": "対応言語：{languages}",
    "plugin_menu_manage": "プラグイン管理",
    "plugin_manage_count": "{count} 個のプラグインが読み込まれています",
    "plugin_manage_select_hint": "プラグインを選択して詳細を表示",
    "plugin_reload_confirm": "すべてのプラグインを再読み込みしますか？現在のプラグインをアンロードして再検出します。",
    "plugin_reload_done": "{count} 個のプラグインを再読み込みしました",
    "plugin_menu_download": "プラグインをダウンロード",
    # Plugin Downloader
    "plugin_dl_title": "プラグインをダウンロード",
    "plugin_dl_refresh": "更新",
    "plugin_dl_col_name": "プラグイン",
    "plugin_dl_col_status": "ステータス",
    "plugin_dl_download": "ダウンロード",
    "plugin_dl_reinstall": "再インストール",
    "plugin_dl_delete": "削除",
    "plugin_dl_close": "閉じる",
    "plugin_dl_installed": "インストール済み",
    "plugin_dl_not_installed": "未インストール",
    "plugin_dl_status_ready": "準備完了",
    "plugin_dl_status_fetching": "プラグイン一覧を取得中...",
    "plugin_dl_status_found": "{count} 個のプラグインが見つかりました",
    "plugin_dl_status_error": "エラー：{error}",
    "plugin_dl_status_downloading": "{name} をダウンロード中...",
    "plugin_dl_status_done": "{name} のダウンロードが完了しました！",
    "plugin_dl_status_deleted": "{name} を削除しました。",
    "plugin_dl_restart_hint": "プラグイン '{name}' をダウンロードしました。Imervue を再起動して有効化してください。",
    "plugin_dl_delete_confirm_title": "プラグインを削除",
    "plugin_dl_delete_confirm": "プラグイン '{name}' を削除しますか？",
    # 右クリックメニュー
    "right_click_show_in_explorer": "エクスプローラーで表示",
    "right_click_copy_path": "パスをコピー",
    "right_click_copy_image": "画像をコピー",
    "right_click_rotate_cw": "時計回りに回転",
    "right_click_rotate_ccw": "反時計回りに回転",
    "right_click_set_wallpaper": "壁紙に設定",
    "right_click_compare": "画像を比較",
    "right_click_slideshow": "スライドショー",
    "right_click_slideshow_stop": "スライドショーを停止",
    # 並べ替えメニュー
    "sort_menu_title": "並べ替え",
    "sort_by_name": "名前順",
    "sort_by_modified": "更新日順",
    "sort_by_created": "作成日順",
    "sort_by_size": "ファイルサイズ順",
    "sort_by_resolution": "解像度順",
    "sort_ascending": "昇順",
    "sort_descending": "降順",
    # フィルターメニュー
    "filter_menu_title": "フィルター",
    "filter_by_extension": "拡張子で絞り込み",
    "filter_by_rating": "評価で絞り込み",
    "filter_ext_all": "すべて",
    "filter_ext_jpg": "JPEG",
    "filter_ext_png": "PNG",
    "filter_ext_bmp": "BMP",
    "filter_ext_tiff": "TIFF",
    "filter_ext_raw": "RAW",
    "filter_rating_all": "すべて",
    "filter_rating_favorited": "お気に入り",
    "filter_clear": "フィルター解除",
    # お気に入り
    "favorite_added": "\u2764 お気に入りに追加",
    "favorite_removed": "お気に入りを解除",
    # 比較
    "compare_title": "画像を比較",
    "compare_2": "2枚で比較",
    "compare_4": "4枚で比較",
    # EXIF サイドバー
    "exif_filename": "ファイル",
    "exif_filesize": "サイズ",
    "exif_created": "作成日時",
    "exif_modified": "更新日時",
    "exif_taken": "撮影日時",
    "exif_make": "メーカー",
    "exif_model": "モデル",
    "exif_lens": "レンズ",
    "exif_focal": "焦点距離",
    "exif_aperture": "絞り",
    "exif_shutter": "シャッター速度",
    "exif_iso": "ISO",
    "exif_ev": "露出補正",
    "exif_wb": "ホワイトバランス",
    "exif_flash": "フラッシュ",
    "exif_resolution": "解像度",
    "exif_no_data": "EXIF データなし",
    # スライドショー
    "slideshow_title": "スライドショー",
    "slideshow_interval": "間隔（秒）：",
    "slideshow_fade": "フェードトランジション",
    "slideshow_start": "開始",
    "slideshow_cancel": "キャンセル",
    # ステータスバー
    "status_loading_progress": "読み込み中 {current}/{total}...",
    "status_loading_image": "画像を読み込み中...",
    "status_ready": "準備完了",
    # Toast
    "toast_path_copied": "パスをコピーしました",
    # 右クリック追加
    "right_click_edit_image": "画像を編集",
    "right_click_batch": "一括操作",
    "batch_rename_title": "一括リネーム",
    "batch_rename_hint": "テンプレート：{name} = 元の名前、{n} = 連番、{ext} = 拡張子",
    "batch_rename_start": "開始番号：",
    "batch_rename_apply": "リネーム",
    "batch_rename_cancel": "キャンセル",
    "batch_move_title": "移動 / コピー",
    "batch_move_mode": "モード",
    "batch_move_move": "移動",
    "batch_move_copy": "コピー",
    "batch_move_apply": "適用",
    "batch_move_cancel": "キャンセル",
    "batch_rotate_cw": "全て時計回りに回転",
    "batch_rotate_ccw": "全て反時計回りに回転",
    # 画像エディター
    "editor_title": "画像エディター",
    "editor_brightness": "明るさ",
    "editor_contrast": "コントラスト",
    "editor_saturation": "彩度",
    "editor_apply_crop": "切り抜きを適用",
    "editor_rotate_cw": "時計回りに回転",
    "editor_rotate_ccw": "反時計回りに回転",
    "editor_reset": "リセット",
    "editor_save_as": "名前を付けて保存...",
    "editor_save": "保存",
    "editor_saved": "保存しました！",
    # EXIF エディター
    "exif_edit_button": "EXIF を編集",
    "exif_editor_title": "EXIF メタデータを編集",
    "exif_editor_no_piexif": "piexif パッケージが必要です。\nインストール：pip install piexif",
    "exif_editor_fields": "メタデータフィールド",
    "exif_editor_save": "保存",
    "exif_editor_cancel": "キャンセル",
    "exif_editor_close": "閉じる",
    "exif_editor_saved": "EXIF を保存しました！",
    "exif_edit_description": "説明",
    "exif_edit_artist": "アーティスト",
    "exif_edit_copyright": "著作権",
    "exif_edit_make": "メーカー",
    "exif_edit_model": "モデル",
    "exif_edit_user_comment": "ユーザーコメント",
    # エクスポートダイアログ
    "export_title": "画像をエクスポート",
    "export_format": "形式：",
    "export_quality": "品質：",
    "export_browse": "参照...",
    "export_save": "保存",
    "export_cancel": "キャンセル",
    "export_saved": "エクスポート完了！",
    # ヒストグラム
    "histogram_toggle": "H キーで RGB ヒストグラムを切替",
    # 無劣化回転
    "lossless_rotate_cw": "無劣化で時計回りに回転",
    "lossless_rotate_ccw": "無劣化で反時計回りに回転",
    "lossless_rotate_done": "無劣化回転を保存しました！",
    "lossless_rotate_fail": "無劣化回転に失敗しました",
    # 右クリックメニュー追加
    "right_click_export": "エクスポート / 名前を付けて保存...",
    "right_click_lossless_rotate": "無劣化回転",
    # アニメーション再生
    "anim_play": "再生",
    "anim_pause": "一時停止",
    "anim_frame_prev": "前のフレーム",
    "anim_frame_next": "次のフレーム",
    "anim_frame_indicator": "フレーム {current}/{total}",
    "anim_speed": "速度：{speed}x",
    # ファイルの関連付け
    "file_assoc_menu": "ファイルの関連付け",
    "file_assoc_register": "「Imervueで開く」を登録",
    "file_assoc_unregister": "ファイルの関連付けを解除",
    "file_assoc_done": "ファイルの関連付けを登録しました！",
    "file_assoc_removed": "ファイルの関連付けを解除しました！",
    "file_assoc_need_admin": "管理者権限が必要です",
    # マルチウィンドウ
    "menu_new_window": "新しいウィンドウ",
    # フィットモード
    "fit_width": "幅に合わせる",
    "fit_height": "高さに合わせる",
    "keyboard_w_tip": "W で幅に合わせる、Shift+W で高さに合わせる",
    # 追加キーボードヒント
    "keyboard_h_tip": "ディープズームモードで H キーを押して RGB ヒストグラムを切替",
    "keyboard_ctrl_v_tip": "Ctrl+V でクリップボードから画像を貼り付け",
    "keyboard_anim_play_tip": "スペースキーでアニメーション画像（GIF/APNG/WebP）を再生/一時停止",
    "keyboard_anim_frame_tip": "< / > でアニメーションをフレーム送り",
    "keyboard_anim_speed_tip": "[ / ] でアニメーション速度を調整",
    # ブックマーク
    "bookmark_title": "ブックマーク",
    "bookmark_open": "開く",
    "bookmark_remove": "削除",
    "bookmark_clear": "すべて削除",
    "bookmark_close": "閉じる",
    "bookmark_count": "{count} 件のブックマーク",
    "bookmark_added": "\u2605 ブックマーク追加",
    "bookmark_removed": "ブックマーク解除",
    "bookmark_add_current": "ブックマークに追加",
    "bookmark_remove_current": "ブックマークを解除",
    "bookmark_clear_confirm_title": "ブックマークを削除",
    "bookmark_clear_confirm": "すべてのブックマークを削除しますか？",
    "keyboard_b_tip": "B キーで現在の画像のブックマークを切替",
    # SVG
    "filter_ext_svg": "SVG",
    # タグ & アルバム
    "tag_album_title": "タグ & アルバム",
    "tag_tab_tags": "タグ",
    "tag_tab_albums": "アルバム",
    "tag_close": "閉じる",
    "tag_count": "{count} 個のタグ",
    "tag_create": "新規タグ",
    "tag_rename": "名前変更",
    "tag_delete": "削除",
    "tag_images": "タグ内の画像：",
    "tag_remove_image": "タグから削除",
    "tag_filter": "ビューアーで表示",
    "tag_create_prompt": "タグ名：",
    "tag_rename_prompt": "新しい名前：",
    "tag_delete_confirm_title": "タグを削除",
    "tag_delete_confirm": "タグ「{name}」を削除しますか？",
    "tag_menu_title": "タグ",
    "tag_create_and_add": "+ 新規タグ...",
    "album_count": "{count} 個のアルバム",
    "album_create": "新規アルバム",
    "album_rename": "名前変更",
    "album_delete": "削除",
    "album_images": "アルバム内の画像：",
    "album_remove_image": "アルバムから削除",
    "album_view": "アルバムを表示",
    "album_create_prompt": "アルバム名：",
    "album_rename_prompt": "新しい名前：",
    "album_delete_confirm_title": "アルバムを削除",
    "album_delete_confirm": "アルバム「{name}」を削除しますか？",
    "album_menu_title": "アルバム",
    "album_create_and_add": "+ 新規アルバム...",
    "batch_tag_title": "タグに追加",
    "batch_album_title": "アルバムに追加",
    "filter_by_tag": "タグで絞り込み",
    "filter_by_album": "アルバムで絞り込み",
    "filter_no_tags": "（タグなし）",
    "filter_no_albums": "（アルバムなし）",
    "keyboard_t_tip": "T キーでタグ & アルバム管理を開く",
    # 一括エクスポート
    "batch_export_title": "一括エクスポート",
    "batch_export_count": "{count} 枚の画像を選択中",
    "batch_export_resize": "リサイズ",
    "batch_export_max_width": "最大幅：",
    "batch_export_max_height": "最大高さ：",
    "batch_export_start": "エクスポート",
    "batch_export_done": "{success}/{total} 枚をエクスポートしました",
    # GIF / 動画
    "gif_video_title": "GIF / 動画を作成",
    "gif_video_order": "ドラッグで並べ替え（上が最初のフレーム）：",
    "gif_video_move_up": "上へ",
    "gif_video_move_down": "下へ",
    "gif_video_settings": "設定",
    "gif_video_fps": "FPS：",
    "gif_video_width": "幅：",
    "gif_video_height": "高さ：",
    "gif_video_auto": "自動",
    "gif_video_loop": "無限ループ",
    "gif_video_create": "作成",
    "gif_video_save": "名前を付けて保存",
    "gif_video_done": "作成完了：{path}",
}
